==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/ATTRIBUTESETDEFID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "attributesetdefcode",
    "attributesetdefdesc",
    "attributesetdeftype"
})
@XmlRootElement(name = "ATTRIBUTESETDEFID")
public class ATTRIBUTESETDEFID {

    @XmlElement(name = "ATTRIBUTESETDEFCODE", required = true)
    protected String attributesetdefcode;
    @XmlElement(name = "ATTRIBUTESETDEFDESC")
    protected String attributesetdefdesc;
    @XmlElement(name = "ATTRIBUTESETDEFTYPE")
    @XmlSchemaType(name = "string")
    protected ATTRIBUTESETDEFTYPE_Type attributesetdeftype;

    /**
     * Obtient la valeur de la propriété attributesetdefcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getATTRIBUTESETDEFCODE() {
        return attributesetdefcode;
    }

    /**
     * Définit la valeur de la propriété attributesetdefcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setATTRIBUTESETDEFCODE(String value) {
        this.attributesetdefcode = value;
    }

    /**
     * Obtient la valeur de la propriété attributesetdefdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getATTRIBUTESETDEFDESC() {
        return attributesetdefdesc;
    }

    /**
     * Définit la valeur de la propriété attributesetdefdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setATTRIBUTESETDEFDESC(String value) {
        this.attributesetdefdesc = value;
    }

    /**
     * Obtient la valeur de la propriété attributesetdeftype.
     * 
     * @return
     *     possible object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public ATTRIBUTESETDEFTYPE_Type getATTRIBUTESETDEFTYPE() {
        return attributesetdeftype;
    }

    /**
     * Définit la valeur de la propriété attributesetdeftype.
     * 
     * @param value
     *     allowed object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public void setATTRIBUTESETDEFTYPE(ATTRIBUTESETDEFTYPE_Type value) {
        this.attributesetdeftype = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/ATTRIBUTESETDEFID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "attributesetdefcode",
    "attributesetdefdesc",
    "attributesetdeftype"
})
@XmlRootElement(name = "ATTRIBUTESETDEFID")
public class ATTRIBUTESETDEFID {

    @XmlElement(name = "ATTRIBUTESETDEFCODE", required = true)
    protected String attributesetdefcode;
    @XmlElement(name = "ATTRIBUTESETDEFDESC")
    protected String attributesetdefdesc;
    @XmlElement(name = "ATTRIBUTESETDEFTYPE")
    @XmlSchemaType(name = "string")
    protected ATTRIBUTESETDEFTYPE_Type attributesetdeftype;

    /**
     * Gets the value of the attributesetdefcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getATTRIBUTESETDEFCODE() {
        return attributesetdefcode;
    }

    /**
     * Sets the value of the attributesetdefcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setATTRIBUTESETDEFCODE(String value) {
        this.attributesetdefcode = value;
    }

    /**
     * Gets the value of the attributesetdefdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getATTRIBUTESETDEFDESC() {
        return attributesetdefdesc;
    }

    /**
     * Sets the value of the attributesetdefdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setATTRIBUTESETDEFDESC(String value) {
        this.attributesetdefdesc = value;
    }

    /**
     * Gets the value of the attributesetdeftype property.
     * 
     * @return
     *     possible object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public ATTRIBUTESETDEFTYPE_Type getATTRIBUTESETDEFTYPE() {
        return attributesetdeftype;
    }

    /**
     * Sets the value of the attributesetdeftype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public void setATTRIBUTESETDEFTYPE(ATTRIBUTESETDEFTYPE_Type value) {
        this.attributesetdeftype = value;
    }

}
